==> jc-1.4.0.tar.gz: gnu/java/awt/color/GrayScaleConverter.h <==
// public class gnu.java.awt.color.GrayScaleConverter

// class file dependencies
// @dep_class f7156cbc88da516a gnu_java_awt_color_GrayScaleConverter
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_GrayScaleConverter_H_
#define _JC_gnu_java_awt_color_GrayScaleConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs	_jc_gnu_java_awt_color_GrayScaleConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs	_jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$refs	_jc_gnu_java_awt_color_GrayScaleConverter$refs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$nonrefs	_jc_gnu_java_awt_color_GrayScaleConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$object	_jc_gnu_java_awt_color_GrayScaleConverter$object;

typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct	_jc_gnu_java_awt_color_GrayScaleConverter$fields_struct;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vmethods	_jc_gnu_java_awt_color_GrayScaleConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vtable	_jc_gnu_java_awt_color_GrayScaleConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vtype	_jc_gnu_java_awt_color_GrayScaleConverter$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct _jc_gnu_java_awt_color_GrayScaleConverter$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *);

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$toRGB$8e7372c09e81aa9c;

// Static methods
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *);
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *);
};

// Vtable
struct _jc_gnu_java_awt_color_GrayScaleConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_GrayScaleConverter$vmethods	gnu_java_awt_color_GrayScaleConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_GrayScaleConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_GrayScaleConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs {
	_jc_double_array	*coeff;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayScaleConverter$refs {
    _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs	gnu_java_awt_color_GrayScaleConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayScaleConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs	gnu_java_awt_color_GrayScaleConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$object {
	_jc_gnu_java_awt_color_GrayScaleConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_GrayScaleConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_GrayScaleConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_GrayScaleConverter$vtype _jc_gnu_java_awt_color_GrayScaleConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_GrayScaleConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_GrayScaleConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_GrayScaleConverter_H_ */

==> jc-1.4.6.tar.gz: gnu/java/awt/color/GrayScaleConverter.h <==
// public class gnu.java.awt.color.GrayScaleConverter

// class file dependencies
// @dep_class 28b1e30073d2fea3 gnu_java_awt_color_GrayScaleConverter
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_awt_color_GrayScaleConverter_H_
#define _JC_gnu_java_awt_color_GrayScaleConverter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs	_jc_gnu_java_awt_color_GrayScaleConverter$sub_refs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs	_jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$refs	_jc_gnu_java_awt_color_GrayScaleConverter$refs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$nonrefs	_jc_gnu_java_awt_color_GrayScaleConverter$nonrefs;
typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$object	_jc_gnu_java_awt_color_GrayScaleConverter$object;

typedef struct _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct	_jc_gnu_java_awt_color_GrayScaleConverter$fields_struct;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vmethods	_jc_gnu_java_awt_color_GrayScaleConverter$vmethods;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vtable	_jc_gnu_java_awt_color_GrayScaleConverter$vtable;
typedef const struct _jc_gnu_java_awt_color_GrayScaleConverter$vtype	_jc_gnu_java_awt_color_GrayScaleConverter$vtype;

// Class fields structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct {
	_jc_float_array	*D50;
};
extern _jc_gnu_java_awt_color_GrayScaleConverter$fields_struct _jc_gnu_java_awt_color_GrayScaleConverter$class_fields;

// Constructors
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$fromCIEXYZ$7b319ba108c72c43(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$fromRGB$241337c328fb6c81(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$toCIEXYZ$ea146856208217b9(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
extern _jc_float_array *_jc_gnu_java_awt_color_GrayScaleConverter$method$toRGB$8e7372c09e81aa9c(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$fromCIEXYZ$7b319ba108c72c43;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$fromRGB$241337c328fb6c81;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$this$adc93fb6bf4cbffa;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$toCIEXYZ$ea146856208217b9;
extern _jc_method _jc_gnu_java_awt_color_GrayScaleConverter$method_info$toRGB$8e7372c09e81aa9c;

// Static methods
extern void _jc_gnu_java_awt_color_GrayScaleConverter$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$vmethods {
	_jc_float_array	*(*fromCIEXYZ$7b319ba108c72c43)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*fromRGB$241337c328fb6c81)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toCIEXYZ$ea146856208217b9)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
	_jc_float_array	*(*toRGB$8e7372c09e81aa9c)(_jc_env *, struct _jc_gnu_java_awt_color_GrayScaleConverter$object *, struct _jc_float_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_color_GrayScaleConverter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_color_GrayScaleConverter$vmethods	gnu_java_awt_color_GrayScaleConverter;
};

// Vtype
struct _jc_gnu_java_awt_color_GrayScaleConverter$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_color_GrayScaleConverter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs {
	_jc_double_array	*coeff;
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayScaleConverter$refs {
    _jc_gnu_java_awt_color_GrayScaleConverter$sub_refs	gnu_java_awt_color_GrayScaleConverter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_color_GrayScaleConverter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_color_GrayScaleConverter$sub_nonrefs	gnu_java_awt_color_GrayScaleConverter;
};

// Object instance structure
struct _jc_gnu_java_awt_color_GrayScaleConverter$object {
	_jc_gnu_java_awt_color_GrayScaleConverter$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_color_GrayScaleConverter$vtype	*vtype;
	_jc_gnu_java_awt_color_GrayScaleConverter$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_color_GrayScaleConverter$vtype _jc_gnu_java_awt_color_GrayScaleConverter$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_color_GrayScaleConverter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_color_GrayScaleConverter$class_object;

#endif	/* _JC_gnu_java_awt_color_GrayScaleConverter_H_ */
